%global pkgstatedir %{_sharedstatedir}/arpwatch

Summary:	Network monitoring tools for tracking IP addresses on the network
Name:		arpwatch
Epoch:		2
Version:	3.7
Release:	%mkrel 2
License:	BSD-3-Clause
Group:		Monitoring
URL:		https://ee.lbl.gov/
Source0:	https://ee.lbl.gov/downloads/arpwatch/arpwatch-%{version}.tar.gz
# This file comes from https://standards-oui.ieee.org/oui/oui.csv; it is used
# to generate ethercodes.dat. Because it is unversioned (and frequently
# updated), we store the file directly in the repository with the spec file;
# see the update-oui-csv script.
#
# File oui.csv last fetched 2024-03-28T13:35:28+00:00.
Source1:        oui.csv
Source2:        arpwatch.service
Source3:        arpwatch.sysconfig
Source4:        arp2ethers.8
Source5:        massagevendor.8
Source6:        arpwatch.sysusers

# The latest versions of all “arpwatch-3.1-*” patches were sent upstream by
# email 2021-04-24.

# Fix section numbers in man page cross-references. With minor changes, this
# patch dates all the way back to arpwatch-2.1a4-man.patch, from RHBZ #15442.
Patch:          arpwatch-3.1-man-references.patch
# Add, and document, a -u argument to change to a specified unprivileged user
# after establishing sockets. This combines and improves multiple previous
# patches; see patch header and changelog for notes.
Patch:          arpwatch-3.2-change-user.patch
# Fix nonstandard sort flags in arp2ethers script.
Patch:          arpwatch-3.1-arp2ethers-sort-invocation.patch
# Fix stray rm (of an undefined variable) in example arpfetch script.
Patch:          arpwatch-3.1-arpfetch-stray-rm.patch
# Do not add /usr/local/bin or /usr/local/sbin to the PATH in any scripts
Patch:          arpwatch-3.2-no-usr-local-path.patch
# Do not attempt to search for local libpcap libraries lying around in the
# parent of the build directory, or anywhere else random. This is not expected
# to succeed anyway, but it is better to be sure.
Patch:          arpwatch-3.1-configure-no-local-pcap.patch
# RHBZ #244606: Correctly handle -n 0/32 to allow the user to disable reporting
# bogons from 0.0.0.0.
Patch:          arpwatch-3.1-all-zero-bogon.patch
# When arpwatch is terminated cleanly by a signal (INT/TERM/HUP) handler, the
# exit code should be zero for success instead of nonzero for failure.
Patch:          arpwatch-3.5-exitcode.patch
# When -i is not given, do not just try the first device found, but keep
# checking devices until a usable one is found, if any is available.
# Additionally, handle the case where a device provides both supported and
# unsupported datalink types.
Patch:          arpwatch-3.5-devlookup.patch

# Replace _getshort(), “a glibc function that hasn't been declared in the
# installed headers for many, many years,” with ns_get16(). Fixes C99
# compatibility (https://bugzilla.redhat.com/show_bug.cgi?id=2166336). Sent
# upstream by email 2023-02-01.
Patch:          arpwatch-3.3-c99.patch

BuildRequires:	pkgconfig(libpcap)
BuildRequires:	pkgconfig(python3)

Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
Requires:	sendmail-command

%description
The arpwatch package contains arpwatch and arpsnmp.  Arpwatch and arpsnmp
are both network monitoring tools.  Both utilities monitor Ethernet or
FDDI network traffic and build databases of Ethernet/IP address pairs,
and can report certain changes via email.

Install the arpwatch package if you need networking monitoring devices
which will automatically keep traffic of the IP addresses on your
network.

%prep
%autosetup -p1

# Substitute absolute paths to awk scripts in shell scripts
sed -r -i 's|(-f *)([^[:blank:]+]\.awk)|\1%{_datadir}/arpwatch/\2|' arp2ethers

# Fix default directory in man pages to match ARPDIR in build section. This was
# formerly done by arpwatch-dir-man.patch. For thoroughness, do the same
# replacement in update-ethercodes.sh.in and bihourly.sh, even though they are
# not installed.
sed -r -i 's|/usr/local/arpwatch|%{pkgstatedir}|g' *.8.in *.sh.in *.sh

# Fix Python interpreter path (but note that this script is not installed)
sed -r -i 's|/usr/local/bin/python|%{python3}|g' update-ethercodes.sh.in

# Emailed upstream requesting a separate LICENSE/COPYING file 2022-07-30.
# For now, we extract it from the main source file’s “header” comment.
awk '/^ \* / { print substr($0, 4); } /^ \*\// { exit }' arpwatch.c |
  tee LICENSE

# Fix rights
sed -i -e 's/-m 555/-m 755/g' Makefile.in
sed -i -e 's/-m 444/-m 644/g' Makefile.in

%build
# Prior to version 3.4, this was handled by the configure script. If it is not
# defined, the build failes because time.h is not included in report.c. This
# regregression was reported upstream by email to arpwatch@ee.lbl.gov on
# 2023-09-06.
export CPPFLAGS="${CPPFLAGS-} -DTIME_WITH_SYS_TIME=1"

%configure --with-sendmail=%{_sbindir}/sendmail PYTHON=%{python3}
%make_build \
    ARPDIR=%{_localstatedir}/lib/arpwatch \
    LDFLAGS="%ldflags"

%install
install -p -D -m 0644 %{SOURCE6} '%{buildroot}%{_sysusersdir}/arpwatch.conf'

# The upstream Makefile does not create the directories it requires, so we must
# do it manually. Additionally, it attempts to comment out the installation of
# the init script on non-FreeBSD platforms, but this does not quite work as
# intended. We just let it install the file, then remove it afterwards.
install -d %{buildroot}%{_mandir}/man8 \
    %{buildroot}%{_sbindir} \
    %{buildroot}%{_datadir}/arpwatch \
    %{buildroot}%{pkgstatedir} \
    %{buildroot}%{_unitdir} \
    %{buildroot}%{_prefix}/etc/rc.d

%make_install

install -p -t %{buildroot}%{_datadir}/arpwatch -m 0644 *.awk
install -p -t %{buildroot}%{_sbindir} arp2ethers
install -p massagevendor.py %{buildroot}%{_sbindir}/massagevendor

install -p -t %{buildroot}%{pkgstatedir} -m 0644 *.dat
touch %{buildroot}%{pkgstatedir}/arp.dat- \
    %{buildroot}%{pkgstatedir}/arp.dat.new

install -p -t %{buildroot}%{_unitdir} -m 0644 %{SOURCE2}
%{python3} massagevendor.py < %{SOURCE1} \
    > %{buildroot}%{pkgstatedir}/ethercodes.dat
touch -r %{SOURCE1} ethercodes.dat

# Add an environment/sysconfig file:
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/arpwatch

# Add extra man pages not provided upstream:
install -p -t %{buildroot}%{_mandir}/man8 -m 0644 %{SOURCE4} %{SOURCE5}

# Remove legacy init scripts:
rm -rvf %{buildroot}%{_prefix}/etc/rc.d

%pre
%_pre_useradd arpwatch %{_localstatedir}/lib/arpwatch /bin/sh

%post
%_post_service arpwatch

%preun
%_preun_service arpwatch

%files
%license LICENSE
%doc README CHANGES arpfetch
%config(noreplace) %{_sysconfdir}/sysconfig/arpwatch
%{_sbindir}/*
%{_datadir}/arpwatch/
%{_unitdir}/arpwatch.service
%{_sysusersdir}/arpwatch.conf

%attr(1775,-,arpwatch) %dir %{pkgstatedir}
%attr(0644,arpwatch,arpwatch) %verify(not md5 size mtime) %config(noreplace) %{pkgstatedir}/arp.dat
%attr(0644,arpwatch,arpwatch) %verify(not md5 size mtime) %config(noreplace) %{pkgstatedir}/arp.dat-
%attr(0600,arpwatch,arpwatch) %verify(not md5 size mtime) %ghost %{pkgstatedir}/arp.dat.new
%attr(0644,-,arpwatch) %verify(not md5 size mtime) %config(noreplace) %{pkgstatedir}/ethercodes.dat
# make install uses mode 0444, which is unconventional
%attr(0644,-,-) %{_mandir}/man8/*.8*


%changelog
* Tue Dec 24 2024 wally <wally> 2:3.7-2.mga10
+ Revision: 2129766
- fix file rights during install
- drop postun scriplet actually doing nothing

* Thu Oct 17 2024 mrambo3501 <mrambo3501> 2:3.7-1.mga10
+ Revision: 2107812
- version 3.7

* Mon Apr 15 2024 daviddavid <daviddavid> 2:3.6-1.mga10
+ Revision: 2057758
- new version: 3.6 (sync with fedora)
- switch to systemd unit from initscripts

* Tue Mar 29 2022 umeabot <umeabot> 2:2.1a15-24.mga9
+ Revision: 1831269
- Mageia 9 Mass Rebuild

* Tue Nov 16 2021 ns80 <ns80> 2:2.1a15-23.mga9
+ Revision: 1757143
- resync a bit with openSUSE (mga#29188)

* Tue Jul 06 2021 ns80 <ns80> 2:2.1a15-22.mga9
+ Revision: 1734973
- fix patch arpwatch-2.1a13-drop_root according to what SUSE did for CVE-2021-25321 (mga#29188)

* Tue Nov 10 2020 ns80 <ns80> 2:2.1a15-21.mga8
+ Revision: 1644211
- add Fedora patch for a buffer overflow (mga#27570)

* Mon Jun 29 2020 joequant <joequant> 2:2.1a15-20.mga8
+ Revision: 1600444
- bump version
- fix arm workaround

* Wed Feb 12 2020 umeabot <umeabot> 19.mga8-current
+ Revision: 1508918
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Sep 21 2018 umeabot <umeabot> 2:2.1a15-18.mga7
+ Revision: 1294579
- Mageia 7 Mass Rebuild

* Mon Jun 04 2018 wally <wally> 2:2.1a15-17.mga7
+ Revision: 1234533
- fix build on aarch64

* Fri Mar 23 2018 kekepower <kekepower> 2:2.1a15-16.mga7
+ Revision: 1211489
- Use new make macros

* Thu Feb 04 2016 umeabot <umeabot> 2:2.1a15-15.mga6
+ Revision: 935094
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2:2.1a15-14.mga5
+ Revision: 741602
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2:2.1a15-13.mga5
+ Revision: 677907
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2:2.1a15-12.mga4
+ Revision: 502603
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 2:2.1a15-11.mga3
+ Revision: 346092
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jun 15 2012 luigiwalser <luigiwalser> 2:2.1a15-10.mga3
+ Revision: 260832
- update patch2 to fix CVE-2012-2653 (from debian)

* Wed Apr 18 2012 colin <colin> 2:2.1a15-9.mga2
+ Revision: 231270
- Add LSB headers

* Thu Mar 03 2011 ennael <ennael> 2:2.1a15-8.mga1
+ Revision: 63737
- imported package arpwatch


* Mon Nov 29 2010 Oden Eriksson <oeriksson@mandriva.com> 2:2.1a15-8mdv2011.0
+ Revision: 603184
- rebuild

* Mon Feb 22 2010 Sandro Cazzaniga <kharec@mandriva.org> 2:2.1a15-7mdv2010.1
+ Revision: 509459
- Use %%configure2_5x instead of %%configure.

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 2:2.1a15-6mdv2010.0
+ Revision: 413037
- rebuild

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 2:2.1a15-5mdv2009.1
+ Revision: 316494
- use %%ldflags

* Wed Oct 29 2008 Oden Eriksson <oeriksson@mandriva.com> 2:2.1a15-4mdv2009.1
+ Revision: 298234
- rebuilt against libpcap-1.0.0

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 2:2.1a15-3mdv2009.0
+ Revision: 220356
- rebuild

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Fri Jan 11 2008 Thierry Vignaud <tv@mandriva.org> 2:2.1a15-2mdv2008.1
+ Revision: 148466
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Wed Mar 07 2007 Oden Eriksson <oeriksson@mandriva.com> 2.1a15-1mdv2007.0
+ Revision: 134277
- 2.1a15
- bunzip patches and sources

* Fri Dec 22 2006 Oden Eriksson <oeriksson@mandriva.com> 2:2.1a13-6mdv2007.1
+ Revision: 101574
- Import arpwatch

* Tue May 16 2006 Pablo Saratxaga <pablo@mandriva.com> 2.1a13-6mdk
- changed init script to use generic (translator-friendly) strings

* Fri Oct 07 2005 Oden Eriksson <oeriksson@mandriva.com> 2.1a13-5mdk
- added P2,P3,P4 from fedora, rediffed P2 and P4
- fix deps

* Fri Aug 12 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.1a13-4mdk
- fix rpmlint errors (PreReq)

* Thu Aug 11 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.1a13-3mdk
- fix rpmlint errors (PreReq)

* Thu Jul 14 2005 Oden Eriksson <oeriksson@mandriva.com> 2.1a13-2mdk
- rebuilt against new libpcap-0.9.1 (aka. a "play safe" rebuild)

* Sat Nov 20 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.1a13-1mdk
- 2.1a13
- fixed S1 to make it configurable using S2

* Wed Jun 02 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.1a11-5mdk
- added P1
- misc spec file fixes

* Tue Apr 20 2004 Michael Scherer <misc@mandrake.org> 2.1a11-4mdk
- remove csh requirement

